@@ -131,4 +131,10 @@ class ContrastFaceVerifyRequest(RpcRequest):
 		return self.get_body_params().get('OssBucketName')
 
 	def set_OssBucketName(self,OssBucketName):
-		self.add_body_params('OssBucketName', OssBucketName)
\ No newline at end of file
+		self.add_body_params('OssBucketName', OssBucketName)
+
+	def get_Crop(self):
+		return self.get_body_params().get('Crop')
+
+	def set_Crop(self,Crop):
+		self.add_body_params('Crop', Crop)
\ No newline at end of file
